@@ -11,9 +11,8 @@ logger = logging.getLogger()
 
 def load_month(exchange: Exchange, tmp_path, timeframe='1m'):
     exchan = LoadDataKline(exchange)
-    for i in range(1, 10):
+    for month_index in range(1, 10):
         today = datetime.today()
-        month_index = 1
 
         unix_start = datetime(today.year, today.month - month_index, 1).timestamp() * 1000
         unix_end = (datetime(today.year, today.month + 1 - month_index, 1) - timedelta(seconds=1)).timestamp() * 1000
