@@ -23,17 +23,23 @@ class LoadDataKline:
             if ':' not in sym:
                 self.load(sym, *args, **kwargs)
 
-    def _load(self, symbol, fetch_since, timeframe='1m', limit=100, *args, **kwargs):
-        result = self.exchange.fetch_ohlcv(symbol, timeframe, fetch_since, limit=limit)
-        result = self.exchange.sort_by(result, 0)
-        if len(result) == 0:
-            return False, f'result is empty, fetch_since:{fetch_since}'
+    def _load(self, symbol, fetch_since, timeframe='1m', limit=100, try_times=3, *args, **kwargs):
+        if try_times <= 0:
+            return False, None
 
-        df = pd.DataFrame(result, columns=['timestamp', 'open', 'close', 'low', 'high', 'vol'])
-        df['symbol'] = symbol
-        self.table.insert(json.loads(df.to_json(orient='records')))
-        time.sleep(int(self.exchange.rateLimit / 1000))
-        return True, result
+        try:
+            result = self.exchange.fetch_ohlcv(symbol, timeframe, fetch_since, limit=limit)
+            result = self.exchange.sort_by(result, 0)
+            if len(result) == 0:
+                return False, f'result is empty, fetch_since:{fetch_since}'
+
+            df = pd.DataFrame(result, columns=['timestamp', 'open', 'close', 'low', 'high', 'vol'])
+            df['symbol'] = symbol
+            self.table.insert(json.loads(df.to_json(orient='records')))
+            time.sleep(int(self.exchange.rateLimit / 1000))
+            return True, result
+        except Exception as e:
+            return self._load(symbol, fetch_since, timeframe, limit=limit, try_times=try_times - 1, *args, **kwargs)
 
     def load(self, symbol, timeframe='1m', limit=100, unix_start=None, unix_end=None, *args, **kwargs):
         unix_max, unix_min = self.table.select_symbol_maxmin(symbol)
@@ -54,6 +60,8 @@ class LoadDataKline:
             pbar.set_postfix({'fetch_since': self.exchange.iso8601(result[0][0])})
             unix_temp = result[0][0]
 
+        if unix_max >= unix_end:
+            return
         unix_temp = unix_max
         pbar = tqdm(range(unix_max, unix_end, unix_delta), desc=symbol)
         for _ in pbar:
